/*
 * Copyright 2015 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.client;

/**
 * <p>
 * Listener monitoring the connection state of a {@link ChannelAccessChannel}.
 * </p>
 * 
 * <p>
 * The listeners {@link #connectionStateChanged(ChannelAccessChannel, boolean)}
 * method is called every time the channel's connection state changes (from
 * disconnected to connected or from connected to disconnected). In addition to
 * that it is called once with the current connection state when the listener is
 * registered.
 * </p>
 * 
 * <p>
 * In general, a listener should not run any operations that require an extended
 * amount of time or that even block. Unless explicitly allowed by the
 * implementation, registering such a listener with an object might result in
 * undefined behavior, including a dead lock.
 * </p>
 * 
 * @author Sebastian Marsching
 */
public interface ChannelAccessConnectionListener {

    /**
     * Notifies the listener of a changed connection state for the specified
     * channel. This method is also called once when registering a listener with
     * a channel.
     * 
     * @param channel
     *            Channel Access channel that changed its connection state.
     * @param nowConnected
     *            <code>true</code> if the channel is now connected,
     *            <code>false</code> if it is now disconnected.
     */
    void connectionStateChanged(ChannelAccessChannel channel,
            boolean nowConnected);

}
